@@ -18,7 +18,7 @@
 //! Get the latest version for your `Cargo.toml` from
 //! [crates.io](https://crates.io/crates/http-api-problem).
 //!
-//! Add this crate root:
+//! Add this to your crate root:
 //!
 //! ```rust
 //! extern crate http_api_problem;
@@ -29,7 +29,8 @@
 //! ```rust
 //! use http_api_problem::*;
 //!
-//! let p = HttpApiProblem::with_title_and_type_from_status(HttpStatusCode::NotFound)
+//! let p =
+//!     HttpApiProblem::with_title_and_type_from_status(HttpStatusCode::NotFound)
 //!     .set_detail("detailed explanation")
 //!     .set_instance("/on/1234/do/something");
 //!
@@ -45,7 +46,8 @@
 //! ```rust
 //! use http_api_problem::*;
 //!
-//! let p = HttpApiProblem::with_title_and_type_from_status(428)
+//! let p =
+//!     HttpApiProblem::with_title_and_type_from_status(428)
 //!     .set_detail("detailed explanation")
 //!     .set_instance("/on/1234/do/something");
 //!
@@ -64,7 +66,7 @@
 //!
 //! ### serde + serde_json
 //!
-//! `HttpApiProblem` provides a method to ` wich is a `Vec[u8]`
+//! `HttpApiProblem` provides a method to `` wich is a `Vec[u8]`
 //!
 //! ### iron
 //!
@@ -72,15 +74,12 @@
 //!
 //! ### iron + serde + serde_json
 //!
-//! The `HttpApiProblem` provides a method `to_iron_response` which constructs an iron `iron::response::Response`.
+//! The `HttpApiProblem` provides a method `to_iron_response` which constructs an iron `Response`.
 //! If the `status` field of the `HttpApiProblem` is `None` `500 - Internal Server Error` is the default.
 //!
 //! `From<HttpApiProblem` for `iron::response::Response` will also be there. It simply calls
 //! `to_iron_response`.
 //!
-//! Additionally there will be a function `into_iron_response` which converts anything into
-//! an `iron::response::Response` that can be converted into a `HttpApiProblem`.
-//!
 //! ## License
 //!
 //! `http-api-problem` is primarily distributed under the terms of both the MIT license and the
@@ -243,12 +242,11 @@ impl HttpApiProblem {
     /// ```rust
     /// use http_api_problem::*;
     ///
-    /// let p = HttpApiProblem::new("Error").set_type_url("http://example.com/my/real_error");
+    /// let p =
+    ///     HttpApiProblem::new("Error")
+    ///     .set_type_url("http://example.com/my/real_error");
     ///
-    /// assert_eq!(
-    ///     Some("http://example.com/my/real_error".to_string()),
-    ///     p.type_url
-    /// );
+    /// assert_eq!(Some("http://example.com/my/real_error".to_string()), p.type_url);
     /// assert_eq!(None, p.status);
     /// assert_eq!("Error", p.title);
     /// assert_eq!(None, p.detail);
@@ -310,7 +308,9 @@ impl HttpApiProblem {
     /// ```rust
     /// use http_api_problem::*;
     ///
-    /// let p = HttpApiProblem::new("Error").set_detail("a detailed description");
+    /// let p =
+    ///     HttpApiProblem::new("Error")
+    ///     .set_detail("a detailed description");
     ///
     /// assert_eq!(None, p.type_url);
     /// assert_eq!(None, p.status);
@@ -331,7 +331,9 @@ impl HttpApiProblem {
     /// ```rust
     /// use http_api_problem::*;
     ///
-    /// let p = HttpApiProblem::new("Error").set_instance("/account/1234/withdraw");
+    /// let p =
+    ///     HttpApiProblem::new("Error")
+    ///     .set_instance("/account/1234/withdraw");
     ///
     /// assert_eq!(None, p.type_url);
     /// assert_eq!(None, p.status);
@@ -389,7 +391,7 @@ impl From<HttpStatusCode> for HttpApiProblem {
     }
 }
 
-#[cfg(all(feature = "serde", feature = "serde_json", feature = "iron", test))]
+#[cfg(all(feature = "serde", feature = "serde_json", feature = "iron"))]
 impl From<HttpApiProblem> for ::iron::response::Response {
     fn from(p: HttpApiProblem) -> ::iron::response::Response {
         p.to_iron_response()
@@ -484,10 +486,7 @@ impl HttpStatusCode {
     /// ```rust
     /// use http_api_problem::*;
     ///
-    /// assert_eq!(
-    ///     "Internal Server Error",
-    ///     HttpStatusCode::InternalServerError.title()
-    /// );
+    /// assert_eq!("Internal Server Error", HttpStatusCode::InternalServerError.title());
     /// ```
     pub fn title(&self) -> &'static str {
         use HttpStatusCode::*;
